################################################################################
################################################################################
####                                                                        ####
#### File 4 of replication code for:                                        ####
####   Park, Sunhee and David J. Hendry. "Reassessing Schoenfeld Residual   ####
####     Tests of Proportional Hazards in Political Science Event History   ####
####     Analyses." American Journal of Political Science.                  ####
####                                                                        ####
####      - This file generates Table 1 from the main text and saves it in  ####
####        the directory "tables", and Figures SI.F.1 and SI.F.2 in the    ####
####        online Supporting Information and saves them in the directory   ####
####        "figures".  The file requires the individual R workspaces       ####
####        generated in during the simulation procedure to be in the       ####
####        directory "r_workspaces".                                       ####
####                                                                        ####
################################################################################
################################################################################

#set.wd(...)

library(survival)
library(car)
# For Latex-style font in R graphical devices
#library(extrafont)
#loadfonts(device = 'pdf')
#Sys.setenv(R_GSCMD = 'INSERT GHOSTSCRIPT PATH NAME HERE')
#font_install('fontcm')


################################################################################
## Simulation 1: 0 percent censoring
################################################################################

load('r_workspaces/simulation01.RData')

# z1 tests
sim01.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim01.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim01.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim01.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim01.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim01.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim01.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim01.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim01.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim01.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim01.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim01.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim01.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspace
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 2: 50 percent censoring, random censoring
################################################################################

load('r_workspaces/simulation02.RData')

# z1 tests
sim02.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim02.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim02.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim02.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim02.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim02.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim02.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim02.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim02.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim02.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim02.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim02.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim02.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspace
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 3: 25 percent censoring, random censoring
################################################################################

load('r_workspaces/simulation03.RData')

# z1 tests
sim03.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim03.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim03.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim03.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim03.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim03.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim03.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim03.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim03.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim03.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim03.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim03.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim03.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspace
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 4: 10 percent censoring, random censoring
################################################################################

load('r_workspaces/simulation04.RData')

# z1 tests
sim04.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim04.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim04.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim04.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim04.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim04.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim04.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim04.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim04.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim04.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim04.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim04.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim04.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspaces
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 5: 50 percent censoring, long censored times
################################################################################

load('r_workspaces/simulation05.RData')

# z1 tests
sim05.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim05.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim05.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim05.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim05.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim05.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim05.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim05.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim05.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim05.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim05.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim05.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim05.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspaces
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 6: 25 percent censoring, long censored times
################################################################################

load('r_workspaces/simulation06.RData')

# z1 tests
sim06.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim06.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim06.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim06.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim06.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim06.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim06.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim06.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim06.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim06.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim06.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim06.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim06.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspace
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 7: 10 percent censoring, lng censored times
################################################################################

load('r_workspaces/simulation07.RData')

# z1 tests
sim07.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim07.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim07.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim07.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim07.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim07.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim07.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim07.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim07.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim07.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim07.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim07.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim07.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspace
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 8: 50 percent censoring, short censored times
################################################################################

load('r_workspaces/simulation08.RData')

# z1 tests
sim08.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim08.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim08.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim08.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim08.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim08.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim08.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim08.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim08.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim08.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim08.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim08.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim08.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspace
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 9: 25 percent censoring, short censored times
################################################################################

load('r_workspaces/simulation09.RData')

# z1 tests
sim09.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim09.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim09.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim09.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim09.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim09.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim09.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim09.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim09.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim09.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim09.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim09.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim09.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspace
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Simulation 10: 10 percent censoring, short censored times
################################################################################

load('r_workspaces/simulation10.RData')

# z1 tests
sim10.z1.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.z1.p.id[i] <- sch.id.list[[i]]$table[1, 3]
}
sim10.z1.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.z1.p.ln[i] <- sch.ln.list[[i]]$table[1, 3]
}
sim10.z1.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.z1.p.km[i] <- sch.km.list[[i]]$table[1, 3]
}
sim10.z1.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.z1.p.ra[i] <- sch.ra.list[[i]]$table[1, 3]
}

# z2 tests
sim10.z2.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.z2.p.id[i] <- sch.id.list[[i]]$table[2, 3]
}
sim10.z2.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.z2.p.ln[i] <- sch.ln.list[[i]]$table[2, 3]
}
sim10.z2.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.z2.p.km[i] <- sch.km.list[[i]]$table[2, 3]
}
sim10.z2.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.z2.p.ra[i] <- sch.ra.list[[i]]$table[2, 3]
}

# global tests
sim10.gl.p.id <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.gl.p.id[i] <- sch.id.list[[i]]$table[3, 3]
}
sim10.gl.p.ln <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.gl.p.ln[i] <- sch.ln.list[[i]]$table[3, 3]
}
sim10.gl.p.km <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.gl.p.km[i] <- sch.km.list[[i]]$table[3, 3]
}
sim10.gl.p.ra <- rep(NA, sims)
for ( i in 1:sims ) {
  sim10.gl.p.ra[i] <- sch.ra.list[[i]]$table[3, 3]
}

# clearing workspace
rm(B, b1, b2, data.list, delta, elapsed.time, g, g.inv, g.inv.t, g.inv.t.max,
  g.inv.t.min, g.y, gen.y, H, k, med.t.scale, model.list, n, num.outliers,
  prop.cen, sch.id.list, sch.km.list, sch.ln.list, sch.ra.list, sims, t, t.max,
  t.min)


################################################################################
## Table 1
################################################################################

sim01.z1.p <- cbind(sim01.z1.p.id, sim01.z1.p.ln, sim01.z1.p.km, sim01.z1.p.ra)
sim01.z2.p <- cbind(sim01.z2.p.id, sim01.z2.p.ln, sim01.z2.p.km, sim01.z2.p.ra)
sim01.gl.p <- cbind(sim01.gl.p.id, sim01.gl.p.ln, sim01.gl.p.km, sim01.gl.p.ra)

sim02.z1.p <- cbind(sim02.z1.p.id, sim02.z1.p.ln, sim02.z1.p.km, sim02.z1.p.ra)
sim02.z2.p <- cbind(sim02.z2.p.id, sim02.z2.p.ln, sim02.z2.p.km, sim02.z2.p.ra)
sim02.gl.p <- cbind(sim02.gl.p.id, sim02.gl.p.ln, sim02.gl.p.km, sim02.gl.p.ra)

sim03.z1.p <- cbind(sim03.z1.p.id, sim03.z1.p.ln, sim03.z1.p.km, sim03.z1.p.ra)
sim03.z2.p <- cbind(sim03.z2.p.id, sim03.z2.p.ln, sim03.z2.p.km, sim03.z2.p.ra)
sim03.gl.p <- cbind(sim03.gl.p.id, sim03.gl.p.ln, sim03.gl.p.km, sim03.gl.p.ra)

sim04.z1.p <- cbind(sim04.z1.p.id, sim04.z1.p.ln, sim04.z1.p.km, sim04.z1.p.ra)
sim04.z2.p <- cbind(sim04.z2.p.id, sim04.z2.p.ln, sim04.z2.p.km, sim04.z2.p.ra)
sim04.gl.p <- cbind(sim04.gl.p.id, sim04.gl.p.ln, sim04.gl.p.km, sim04.gl.p.ra)

sim05.z1.p <- cbind(sim05.z1.p.id, sim05.z1.p.ln, sim05.z1.p.km, sim05.z1.p.ra)
sim05.z2.p <- cbind(sim05.z2.p.id, sim05.z2.p.ln, sim05.z2.p.km, sim05.z2.p.ra)
sim05.gl.p <- cbind(sim05.gl.p.id, sim05.gl.p.ln, sim05.gl.p.km, sim05.gl.p.ra)

sim06.z1.p <- cbind(sim06.z1.p.id, sim06.z1.p.ln, sim06.z1.p.km, sim06.z1.p.ra)
sim06.z2.p <- cbind(sim06.z2.p.id, sim06.z2.p.ln, sim06.z2.p.km, sim06.z2.p.ra)
sim06.gl.p <- cbind(sim06.gl.p.id, sim06.gl.p.ln, sim06.gl.p.km, sim06.gl.p.ra)

sim07.z1.p <- cbind(sim07.z1.p.id, sim07.z1.p.ln, sim07.z1.p.km, sim07.z1.p.ra)
sim07.z2.p <- cbind(sim07.z2.p.id, sim07.z2.p.ln, sim07.z2.p.km, sim07.z2.p.ra)
sim07.gl.p <- cbind(sim07.gl.p.id, sim07.gl.p.ln, sim07.gl.p.km, sim07.gl.p.ra)

sim08.z1.p <- cbind(sim08.z1.p.id, sim08.z1.p.ln, sim08.z1.p.km, sim08.z1.p.ra)
sim08.z2.p <- cbind(sim08.z2.p.id, sim08.z2.p.ln, sim08.z2.p.km, sim08.z2.p.ra)
sim08.gl.p <- cbind(sim08.gl.p.id, sim08.gl.p.ln, sim08.gl.p.km, sim08.gl.p.ra)

sim09.z1.p <- cbind(sim09.z1.p.id, sim09.z1.p.ln, sim09.z1.p.km, sim09.z1.p.ra)
sim09.z2.p <- cbind(sim09.z2.p.id, sim09.z2.p.ln, sim09.z2.p.km, sim09.z2.p.ra)
sim09.gl.p <- cbind(sim09.gl.p.id, sim09.gl.p.ln, sim09.gl.p.km, sim09.gl.p.ra)

sim10.z1.p <- cbind(sim10.z1.p.id, sim10.z1.p.ln, sim10.z1.p.km, sim10.z1.p.ra)
sim10.z2.p <- cbind(sim10.z2.p.id, sim10.z2.p.ln, sim10.z2.p.km, sim10.z2.p.ra)
sim10.gl.p <- cbind(sim10.gl.p.id, sim10.gl.p.ln, sim10.gl.p.km, sim10.gl.p.ra)

freqVio <- function (x)
{
  num <- length(x[x < .05])
  num
}

freqDiscrep <- function(x)
{
  num <- freqVio(x)
  ifelse ( num == 0 | num == 4, discrep <- 0, discrep <- 1)
  discrep
}

vio.table <- rbind(
  c(apply(sim01.z1.p, 2, freqVio), sum(apply(sim01.z1.p, 1, freqDiscrep))), 
  c(apply(sim01.z2.p, 2, freqVio), sum(apply(sim01.z2.p, 1, freqDiscrep))), 
  c(apply(sim01.gl.p, 2, freqVio), sum(apply(sim01.gl.p, 1, freqDiscrep))), 
  c(apply(sim02.z1.p, 2, freqVio), sum(apply(sim02.z1.p, 1, freqDiscrep))), 
  c(apply(sim02.z2.p, 2, freqVio), sum(apply(sim02.z2.p, 1, freqDiscrep))), 
  c(apply(sim02.gl.p, 2, freqVio), sum(apply(sim02.gl.p, 1, freqDiscrep))), 
  c(apply(sim03.z1.p, 2, freqVio), sum(apply(sim03.z1.p, 1, freqDiscrep))), 
  c(apply(sim03.z2.p, 2, freqVio), sum(apply(sim03.z2.p, 1, freqDiscrep))), 
  c(apply(sim03.gl.p, 2, freqVio), sum(apply(sim03.gl.p, 1, freqDiscrep))), 
  c(apply(sim04.z1.p, 2, freqVio), sum(apply(sim04.z1.p, 1, freqDiscrep))), 
  c(apply(sim04.z2.p, 2, freqVio), sum(apply(sim04.z2.p, 1, freqDiscrep))), 
  c(apply(sim04.gl.p, 2, freqVio), sum(apply(sim04.gl.p, 1, freqDiscrep))), 
  c(apply(sim05.z1.p, 2, freqVio), sum(apply(sim05.z1.p, 1, freqDiscrep))), 
  c(apply(sim05.z2.p, 2, freqVio), sum(apply(sim05.z2.p, 1, freqDiscrep))), 
  c(apply(sim05.gl.p, 2, freqVio), sum(apply(sim05.gl.p, 1, freqDiscrep))), 
  c(apply(sim06.z1.p, 2, freqVio), sum(apply(sim06.z1.p, 1, freqDiscrep))), 
  c(apply(sim06.z2.p, 2, freqVio), sum(apply(sim06.z2.p, 1, freqDiscrep))), 
  c(apply(sim06.gl.p, 2, freqVio), sum(apply(sim06.gl.p, 1, freqDiscrep))), 
  c(apply(sim07.z1.p, 2, freqVio), sum(apply(sim07.z1.p, 1, freqDiscrep))), 
  c(apply(sim07.z2.p, 2, freqVio), sum(apply(sim07.z2.p, 1, freqDiscrep))), 
  c(apply(sim07.gl.p, 2, freqVio), sum(apply(sim07.gl.p, 1, freqDiscrep))), 
  c(apply(sim08.z1.p, 2, freqVio), sum(apply(sim08.z1.p, 1, freqDiscrep))), 
  c(apply(sim08.z2.p, 2, freqVio), sum(apply(sim08.z2.p, 1, freqDiscrep))), 
  c(apply(sim08.gl.p, 2, freqVio), sum(apply(sim08.gl.p, 1, freqDiscrep))), 
  c(apply(sim09.z1.p, 2, freqVio), sum(apply(sim09.z1.p, 1, freqDiscrep))), 
  c(apply(sim09.z2.p, 2, freqVio), sum(apply(sim09.z2.p, 1, freqDiscrep))), 
  c(apply(sim09.gl.p, 2, freqVio), sum(apply(sim09.gl.p, 1, freqDiscrep))), 
  c(apply(sim10.z1.p, 2, freqVio), sum(apply(sim10.z1.p, 1, freqDiscrep))), 
  c(apply(sim10.z2.p, 2, freqVio), sum(apply(sim10.z2.p, 1, freqDiscrep))), 
  c(apply(sim10.gl.p, 2, freqVio), sum(apply(sim10.gl.p, 1, freqDiscrep))))

colnames(vio.table) <- c('t', 'ln.t', 'KM.t', 'Rank.t', 'Discrepancies')
rownames(vio.table) <- c('None         0.00     Z1', 'None         0.00     Z2',
  'None         0.00 Global', 'Uniform      0.50     Z1',
  'Uniform      0.50     Z2', 'Uniform      0.50 Global',
  'Uniform      0.25     Z1', 'Uniform      0.25     Z2',
  'Uniform      0.25 Global', 'Uniform      0.10     Z1',
  'Uniform      0.10     Z2', 'Uniform      0.10 Global',
  'Long Biased  0.50     Z1', 'Long Biased  0.50     Z2',
  'Long Biased  0.50 Global', 'Long Biased  0.25     Z1',
  'Long Biased  0.25     Z2', 'Long Biased  0.25 Global',
  'Long Biased  0.10     Z1', 'Long Biased  0.10     Z2',
  'Long Biased  0.10 Global', 'Short Biased 0.50     Z1',
  'Short Biased 0.50     Z2', 'Short Biased 0.50 Global',
  'Short Biased 0.25     Z1', 'Short Biased 0.25     Z2',
  'Short Biased 0.25 Global', 'Short Biased 0.10     Z1',
  'Short Biased 0.10     Z2', 'Short Biased 0.10 Global')

sink(file = 'tables/table-01.txt')
  cat('Table 1', '\n\n\n')
  data.frame(vio.table)[, 1:4]
  cat('\n\n\n\n\n\n')
  cat('Table 1 supplemental information', '\n\n\n')
  data.frame(vio.table)
sink()

load('r_workspaces/simulation01.RData')
example.model <- coxph(Surv(t0, t, d) ~ z1 + z2, data = data.list[[17]])

################################################################################
## Figures SI.F.1 and SI.F.2 - Example plots from simulation 17 of no censoring
##   scenario
################################################################################
zphPlot2(cox.fit = example.model, z.num = 1, directory = 'figures',
  fig.name = 'figure-si-f01')
zphPlot2(cox.fit = example.model, z.num = 2, directory = 'figures',
  fig.name = 'figure-si-f02')

rm(data.list, model.list, sch.id.list, sch.ln.list, sch.km.list, sch.ra.list,
  elapsed.time, prop.cen, delta, med.t.scale, g.y, d.biased, d0, d1, success)
